# Driverless AI Experiment: `{{ experiment.description }}`

Generated on: {{ generated_on }}

Generated by: {{ generated_by }}

## Table of Contents

1. [Experiment Overview](#experiment-overview)
2. [Data Overview](#data-overview)
3. [Methodology](#methodology)
4. [Data Sampling](#data-sampling)
5. [Validation Strategy](#validation-strategy)
6. [Model Tuning](#model-tuning)
7. [Feature Evolution](#feature-evolution)
8. [Feature Transformation](#feature-transformation)
9. [Final Model](#final-model)
10. [Alternative Models](#alternative-models)
11. [Deployment](#deployment)
12. [Partial Dependence Plots](#pdp){% if shap.has_shap %}
14. [Shapley Values](#shap){% endif %}{% if mli and mli.is_valid() %}
15. [Global K-LIME GLM Coefficients](#klime)
14. [Surrogate Decision Tree](#dt){% endif %}
16. [Appendix](#appendix)

## Experiment Overview <a name="experiment-overview"></a>

{{section.render('Experiment Overview.template')}}

## Data Overview <a name="data-overview"></a>

{{section.render('Data Overview.template')}}

## Methodology <a name="methodology"></a>

{{section.render('Methodology.template')}}

## Data Sampling <a name="data-sampling"></a>

{{section.render('Data Sampling.template')}}

## Validation Strategy <a name="validation-strategy"></a>

{{section.render('Validation Strategy.template')}}

## Model Tuning <a name="model-tuning"></a>

{{section.render('Model Tuning.template')}}

## Feature Evolution <a name="feature-evolution"></a>

{{section.render('Feature Evolution.template')}}

## Feature Transformation <a name="feature-transformation"></a>

{{section.render('Feature Transformations.template')}}
{{ section.render('Feature Transformations.DAI Monotonicity Constraints')}}

## Final Model <a name="final-model"></a>

{{section.render('Final Model.template')}}

## Alternative Models <a name="alternative-models"></a>

{{section.render('Alternative Models.template')}}

## Deployment <a name="deployment"></a>

{{section.render('Deployment.template')}}

## Partial Dependence Plots <a name="pdp"></a>

{% if pdp != None %}
{{section.render('Partial Dependence Plots.template')}}
{% else %}
Partial Dependence Plots not computed for this experiment.
{% endif %}

{% if shap != None %}
{% if shap.has_shap %}
## Shapley Values <a name="shap"></a>

{{ section.render('MLI.Shapley Contributions') }}
{% endif %}
{% endif %}

{% if mli and mli.is_valid() %} 

## Global K-LIME GLM Coefficients <a name="klime"></a>

{% if mli.has_klime() %} 

{{section.render('GLM.template')}}

{% else %}

K-LIME was not run or is not supported for the current problem type.

{% endif %}

## Surrogate Decision Tree <a name="dt"></a>

{% if mli.has_dt() %} 

{{section.render('MLI.Surrogate DT')}}

{% else %}

Surrogate Decision Tree was not built or is not supported for the current problem type.

{% endif %}

{% endif %}


## Appendix <a name="appendix"></a>

{{section.render('Appendix.template')}}
